from __future__ import absolute_import

# flake8: noqa

# import apis into api package
from wodby.api.application_api import ApplicationApi
from wodby.api.backup_api import BackupApi
from wodby.api.domain_api import DomainApi
from wodby.api.git_repository_api import GitRepositoryApi
from wodby.api.instance_api import InstanceApi
from wodby.api.organization_api import OrganizationApi
from wodby.api.server_api import ServerApi
from wodby.api.stack_api import StackApi
from wodby.api.task_api import TaskApi
from wodby.api.user_api import UserApi



# coding: utf-8

"""
    Wodby API Client

    Wodby Developer Documentation https://wodby.com/docs/dev  # noqa: E501

    OpenAPI spec version: 3.0.5
    
    Generated by: https://github.com/swagger-api/swagger-codegen.git
"""


import pprint
import re  # noqa: F401

import six

from wodby.models.instance_type import InstanceType  # noqa: F401,E501
from wodby.models.request_app_create_git import RequestAppCreateGit  # noqa: F401,E501
from wodby.models.request_app_create_services import RequestAppCreateServices  # noqa: F401,E501
from wodby.models.uuid import Uuid  # noqa: F401,E501


class RequestAppCreate(object):
    """NOTE: This class is auto generated by the swagger code generator program.

    Do not edit the class manually.
    """

    """
    Attributes:
      swagger_types (dict): The key is attribute name
                            and the value is attribute type.
      attribute_map (dict): The key is attribute name
                            and the value is json key in definition.
    """
    swagger_types = {
        'deployment_type': 'str',
        'docroot': 'str',
        'git': 'RequestAppCreateGit',
        'instance_name': 'str',
        'instance_title': 'str',
        'instance_type': 'InstanceType',
        'name': 'str',
        'org_id': 'Uuid',
        'post_deployment': 'bool',
        'server_id': 'Uuid',
        'services': 'list[RequestAppCreateServices]',
        'sitename': 'str',
        'stack_id': 'str',
        'title': 'str'
    }

    attribute_map = {
        'deployment_type': 'deployment_type',
        'docroot': 'docroot',
        'git': 'git',
        'instance_name': 'instance_name',
        'instance_title': 'instance_title',
        'instance_type': 'instance_type',
        'name': 'name',
        'org_id': 'org_id',
        'post_deployment': 'post_deployment',
        'server_id': 'server_id',
        'services': 'services',
        'sitename': 'sitename',
        'stack_id': 'stack_id',
        'title': 'title'
    }

    def __init__(self, deployment_type='vanilla', docroot=None, git=None, instance_name=None, instance_title=None, instance_type=None, name=None, org_id=None, post_deployment=None, server_id=None, services=None, sitename=None, stack_id=None, title=None):  # noqa: E501
        """RequestAppCreate - a model defined in Swagger"""  # noqa: E501

        self._deployment_type = None
        self._docroot = None
        self._git = None
        self._instance_name = None
        self._instance_title = None
        self._instance_type = None
        self._name = None
        self._org_id = None
        self._post_deployment = None
        self._server_id = None
        self._services = None
        self._sitename = None
        self._stack_id = None
        self._title = None
        self.discriminator = None

        if deployment_type is not None:
            self.deployment_type = deployment_type
        if docroot is not None:
            self.docroot = docroot
        if git is not None:
            self.git = git
        if instance_name is not None:
            self.instance_name = instance_name
        if instance_title is not None:
            self.instance_title = instance_title
        if instance_type is not None:
            self.instance_type = instance_type
        self.name = name
        self.org_id = org_id
        if post_deployment is not None:
            self.post_deployment = post_deployment
        self.server_id = server_id
        if services is not None:
            self.services = services
        if sitename is not None:
            self.sitename = sitename
        self.stack_id = stack_id
        if title is not None:
            self.title = title

    @property
    def deployment_type(self):
        """Gets the deployment_type of this RequestAppCreate.  # noqa: E501


        :return: The deployment_type of this RequestAppCreate.  # noqa: E501
        :rtype: str
        """
        return self._deployment_type

    @deployment_type.setter
    def deployment_type(self, deployment_type):
        """Sets the deployment_type of this RequestAppCreate.


        :param deployment_type: The deployment_type of this RequestAppCreate.  # noqa: E501
        :type: str
        """
        allowed_values = ["vanilla", "git", "ci"]  # noqa: E501
        if deployment_type not in allowed_values:
            raise ValueError(
                "Invalid value for `deployment_type` ({0}), must be one of {1}"  # noqa: E501
                .format(deployment_type, allowed_values)
            )

        self._deployment_type = deployment_type

    @property
    def docroot(self):
        """Gets the docroot of this RequestAppCreate.  # noqa: E501


        :return: The docroot of this RequestAppCreate.  # noqa: E501
        :rtype: str
        """
        return self._docroot

    @docroot.setter
    def docroot(self, docroot):
        """Sets the docroot of this RequestAppCreate.


        :param docroot: The docroot of this RequestAppCreate.  # noqa: E501
        :type: str
        """

        self._docroot = docroot

    @property
    def git(self):
        """Gets the git of this RequestAppCreate.  # noqa: E501


        :return: The git of this RequestAppCreate.  # noqa: E501
        :rtype: RequestAppCreateGit
        """
        return self._git

    @git.setter
    def git(self, git):
        """Sets the git of this RequestAppCreate.


        :param git: The git of this RequestAppCreate.  # noqa: E501
        :type: RequestAppCreateGit
        """

        self._git = git

    @property
    def instance_name(self):
        """Gets the instance_name of this RequestAppCreate.  # noqa: E501


        :return: The instance_name of this RequestAppCreate.  # noqa: E501
        :rtype: str
        """
        return self._instance_name

    @instance_name.setter
    def instance_name(self, instance_name):
        """Sets the instance_name of this RequestAppCreate.


        :param instance_name: The instance_name of this RequestAppCreate.  # noqa: E501
        :type: str
        """
        if instance_name is not None and not re.search('^[a-z0-9][a-z0-9-]{0,18}[a-z0-9]$', instance_name):  # noqa: E501
            raise ValueError("Invalid value for `instance_name`, must be a follow pattern or equal to `/^[a-z0-9][a-z0-9-]{0,18}[a-z0-9]$/`")  # noqa: E501

        self._instance_name = instance_name

    @property
    def instance_title(self):
        """Gets the instance_title of this RequestAppCreate.  # noqa: E501


        :return: The instance_title of this RequestAppCreate.  # noqa: E501
        :rtype: str
        """
        return self._instance_title

    @instance_title.setter
    def instance_title(self, instance_title):
        """Sets the instance_title of this RequestAppCreate.


        :param instance_title: The instance_title of this RequestAppCreate.  # noqa: E501
        :type: str
        """

        self._instance_title = instance_title

    @property
    def instance_type(self):
        """Gets the instance_type of this RequestAppCreate.  # noqa: E501


        :return: The instance_type of this RequestAppCreate.  # noqa: E501
        :rtype: InstanceType
        """
        return self._instance_type

    @instance_type.setter
    def instance_type(self, instance_type):
        """Sets the instance_type of this RequestAppCreate.


        :param instance_type: The instance_type of this RequestAppCreate.  # noqa: E501
        :type: InstanceType
        """

        self._instance_type = instance_type

    @property
    def name(self):
        """Gets the name of this RequestAppCreate.  # noqa: E501


        :return: The name of this RequestAppCreate.  # noqa: E501
        :rtype: str
        """
        return self._name

    @name.setter
    def name(self, name):
        """Sets the name of this RequestAppCreate.


        :param name: The name of this RequestAppCreate.  # noqa: E501
        :type: str
        """
        if name is None:
            raise ValueError("Invalid value for `name`, must not be `None`")  # noqa: E501
        if name is not None and not re.search('^[a-z0-9][a-z0-9-]{0,28}[a-z0-9]$', name):  # noqa: E501
            raise ValueError("Invalid value for `name`, must be a follow pattern or equal to `/^[a-z0-9][a-z0-9-]{0,28}[a-z0-9]$/`")  # noqa: E501

        self._name = name

    @property
    def org_id(self):
        """Gets the org_id of this RequestAppCreate.  # noqa: E501


        :return: The org_id of this RequestAppCreate.  # noqa: E501
        :rtype: Uuid
        """
        return self._org_id

    @org_id.setter
    def org_id(self, org_id):
        """Sets the org_id of this RequestAppCreate.


        :param org_id: The org_id of this RequestAppCreate.  # noqa: E501
        :type: Uuid
        """
        if org_id is None:
            raise ValueError("Invalid value for `org_id`, must not be `None`")  # noqa: E501

        self._org_id = org_id

    @property
    def post_deployment(self):
        """Gets the post_deployment of this RequestAppCreate.  # noqa: E501


        :return: The post_deployment of this RequestAppCreate.  # noqa: E501
        :rtype: bool
        """
        return self._post_deployment

    @post_deployment.setter
    def post_deployment(self, post_deployment):
        """Sets the post_deployment of this RequestAppCreate.


        :param post_deployment: The post_deployment of this RequestAppCreate.  # noqa: E501
        :type: bool
        """

        self._post_deployment = post_deployment

    @property
    def server_id(self):
        """Gets the server_id of this RequestAppCreate.  # noqa: E501


        :return: The server_id of this RequestAppCreate.  # noqa: E501
        :rtype: Uuid
        """
        return self._server_id

    @server_id.setter
    def server_id(self, server_id):
        """Sets the server_id of this RequestAppCreate.


        :param server_id: The server_id of this RequestAppCreate.  # noqa: E501
        :type: Uuid
        """
        if server_id is None:
            raise ValueError("Invalid value for `server_id`, must not be `None`")  # noqa: E501

        self._server_id = server_id

    @property
    def services(self):
        """Gets the services of this RequestAppCreate.  # noqa: E501


        :return: The services of this RequestAppCreate.  # noqa: E501
        :rtype: list[RequestAppCreateServices]
        """
        return self._services

    @services.setter
    def services(self, services):
        """Sets the services of this RequestAppCreate.


        :param services: The services of this RequestAppCreate.  # noqa: E501
        :type: list[RequestAppCreateServices]
        """

        self._services = services

    @property
    def sitename(self):
        """Gets the sitename of this RequestAppCreate.  # noqa: E501


        :return: The sitename of this RequestAppCreate.  # noqa: E501
        :rtype: str
        """
        return self._sitename

    @sitename.setter
    def sitename(self, sitename):
        """Sets the sitename of this RequestAppCreate.


        :param sitename: The sitename of this RequestAppCreate.  # noqa: E501
        :type: str
        """

        self._sitename = sitename

    @property
    def stack_id(self):
        """Gets the stack_id of this RequestAppCreate.  # noqa: E501


        :return: The stack_id of this RequestAppCreate.  # noqa: E501
        :rtype: str
        """
        return self._stack_id

    @stack_id.setter
    def stack_id(self, stack_id):
        """Sets the stack_id of this RequestAppCreate.


        :param stack_id: The stack_id of this RequestAppCreate.  # noqa: E501
        :type: str
        """
        if stack_id is None:
            raise ValueError("Invalid value for `stack_id`, must not be `None`")  # noqa: E501

        self._stack_id = stack_id

    @property
    def title(self):
        """Gets the title of this RequestAppCreate.  # noqa: E501


        :return: The title of this RequestAppCreate.  # noqa: E501
        :rtype: str
        """
        return self._title

    @title.setter
    def title(self, title):
        """Sets the title of this RequestAppCreate.


        :param title: The title of this RequestAppCreate.  # noqa: E501
        :type: str
        """

        self._title = title

    def to_dict(self):
        """Returns the model properties as a dict"""
        result = {}

        for attr, _ in six.iteritems(self.swagger_types):
            value = getattr(self, attr)
            if isinstance(value, list):
                result[attr] = list(map(
                    lambda x: x.to_dict() if hasattr(x, "to_dict") else x,
                    value
                ))
            elif hasattr(value, "to_dict"):
                result[attr] = value.to_dict()
            elif isinstance(value, dict):
                result[attr] = dict(map(
                    lambda item: (item[0], item[1].to_dict())
                    if hasattr(item[1], "to_dict") else item,
                    value.items()
                ))
            else:
                result[attr] = value

        return result

    def to_str(self):
        """Returns the string representation of the model"""
        return pprint.pformat(self.to_dict())

    def __repr__(self):
        """For `print` and `pprint`"""
        return self.to_str()

    def __eq__(self, other):
        """Returns true if both objects are equal"""
        if not isinstance(other, RequestAppCreate):
            return False

        return self.__dict__ == other.__dict__

    def __ne__(self, other):
        """Returns true if both objects are not equal"""
        return not self == other



# coding: utf-8

"""
    Wodby API Client

    Wodby Developer Documentation https://wodby.com/docs/dev  # noqa: E501

    OpenAPI spec version: 3.0.5
    
    Generated by: https://github.com/swagger-api/swagger-codegen.git
"""


import pprint
import re  # noqa: F401

import six


class Task(object):
    """NOTE: This class is auto generated by the swagger code generator program.

    Do not edit the class manually.
    """

    """
    Attributes:
      swagger_types (dict): The key is attribute name
                            and the value is attribute type.
      attribute_map (dict): The key is attribute name
                            and the value is json key in definition.
    """
    swagger_types = {
        'created': 'int',
        'end': 'int',
        'id': 'str',
        'org_id': 'str',
        'start': 'int',
        'status': 'str',
        'title': 'str',
        'ttl': 'int',
        'updated': 'int'
    }

    attribute_map = {
        'created': 'created',
        'end': 'end',
        'id': 'id',
        'org_id': 'org_id',
        'start': 'start',
        'status': 'status',
        'title': 'title',
        'ttl': 'ttl',
        'updated': 'updated'
    }

    def __init__(self, created=None, end=None, id=None, org_id=None, start=None, status=None, title=None, ttl=None, updated=None):  # noqa: E501
        """Task - a model defined in Swagger"""  # noqa: E501

        self._created = None
        self._end = None
        self._id = None
        self._org_id = None
        self._start = None
        self._status = None
        self._title = None
        self._ttl = None
        self._updated = None
        self.discriminator = None

        self.created = created
        if end is not None:
            self.end = end
        self.id = id
        self.org_id = org_id
        if start is not None:
            self.start = start
        self.status = status
        self.title = title
        self.ttl = ttl
        self.updated = updated

    @property
    def created(self):
        """Gets the created of this Task.  # noqa: E501


        :return: The created of this Task.  # noqa: E501
        :rtype: int
        """
        return self._created

    @created.setter
    def created(self, created):
        """Sets the created of this Task.


        :param created: The created of this Task.  # noqa: E501
        :type: int
        """
        if created is None:
            raise ValueError("Invalid value for `created`, must not be `None`")  # noqa: E501

        self._created = created

    @property
    def end(self):
        """Gets the end of this Task.  # noqa: E501


        :return: The end of this Task.  # noqa: E501
        :rtype: int
        """
        return self._end

    @end.setter
    def end(self, end):
        """Sets the end of this Task.


        :param end: The end of this Task.  # noqa: E501
        :type: int
        """

        self._end = end

    @property
    def id(self):
        """Gets the id of this Task.  # noqa: E501


        :return: The id of this Task.  # noqa: E501
        :rtype: str
        """
        return self._id

    @id.setter
    def id(self, id):
        """Sets the id of this Task.


        :param id: The id of this Task.  # noqa: E501
        :type: str
        """
        if id is None:
            raise ValueError("Invalid value for `id`, must not be `None`")  # noqa: E501

        self._id = id

    @property
    def org_id(self):
        """Gets the org_id of this Task.  # noqa: E501


        :return: The org_id of this Task.  # noqa: E501
        :rtype: str
        """
        return self._org_id

    @org_id.setter
    def org_id(self, org_id):
        """Sets the org_id of this Task.


        :param org_id: The org_id of this Task.  # noqa: E501
        :type: str
        """
        if org_id is None:
            raise ValueError("Invalid value for `org_id`, must not be `None`")  # noqa: E501

        self._org_id = org_id

    @property
    def start(self):
        """Gets the start of this Task.  # noqa: E501


        :return: The start of this Task.  # noqa: E501
        :rtype: int
        """
        return self._start

    @start.setter
    def start(self, start):
        """Sets the start of this Task.


        :param start: The start of this Task.  # noqa: E501
        :type: int
        """

        self._start = start

    @property
    def status(self):
        """Gets the status of this Task.  # noqa: E501


        :return: The status of this Task.  # noqa: E501
        :rtype: str
        """
        return self._status

    @status.setter
    def status(self, status):
        """Sets the status of this Task.


        :param status: The status of this Task.  # noqa: E501
        :type: str
        """
        if status is None:
            raise ValueError("Invalid value for `status`, must not be `None`")  # noqa: E501
        allowed_values = ["waiting", "in_progress", "done", "failed", "canceled"]  # noqa: E501
        if status not in allowed_values:
            raise ValueError(
                "Invalid value for `status` ({0}), must be one of {1}"  # noqa: E501
                .format(status, allowed_values)
            )

        self._status = status

    @property
    def title(self):
        """Gets the title of this Task.  # noqa: E501


        :return: The title of this Task.  # noqa: E501
        :rtype: str
        """
        return self._title

    @title.setter
    def title(self, title):
        """Sets the title of this Task.


        :param title: The title of this Task.  # noqa: E501
        :type: str
        """
        if title is None:
            raise ValueError("Invalid value for `title`, must not be `None`")  # noqa: E501

        self._title = title

    @property
    def ttl(self):
        """Gets the ttl of this Task.  # noqa: E501


        :return: The ttl of this Task.  # noqa: E501
        :rtype: int
        """
        return self._ttl

    @ttl.setter
    def ttl(self, ttl):
        """Sets the ttl of this Task.


        :param ttl: The ttl of this Task.  # noqa: E501
        :type: int
        """
        if ttl is None:
            raise ValueError("Invalid value for `ttl`, must not be `None`")  # noqa: E501

        self._ttl = ttl

    @property
    def updated(self):
        """Gets the updated of this Task.  # noqa: E501


        :return: The updated of this Task.  # noqa: E501
        :rtype: int
        """
        return self._updated

    @updated.setter
    def updated(self, updated):
        """Sets the updated of this Task.


        :param updated: The updated of this Task.  # noqa: E501
        :type: int
        """
        if updated is None:
            raise ValueError("Invalid value for `updated`, must not be `None`")  # noqa: E501

        self._updated = updated

    def to_dict(self):
        """Returns the model properties as a dict"""
        result = {}

        for attr, _ in six.iteritems(self.swagger_types):
            value = getattr(self, attr)
            if isinstance(value, list):
                result[attr] = list(map(
                    lambda x: x.to_dict() if hasattr(x, "to_dict") else x,
                    value
                ))
            elif hasattr(value, "to_dict"):
                result[attr] = value.to_dict()
            elif isinstance(value, dict):
                result[attr] = dict(map(
                    lambda item: (item[0], item[1].to_dict())
                    if hasattr(item[1], "to_dict") else item,
                    value.items()
                ))
            else:
                result[attr] = value

        return result

    def to_str(self):
        """Returns the string representation of the model"""
        return pprint.pformat(self.to_dict())

    def __repr__(self):
        """For `print` and `pprint`"""
        return self.to_str()

    def __eq__(self, other):
        """Returns true if both objects are equal"""
        if not isinstance(other, Task):
            return False

        return self.__dict__ == other.__dict__

    def __ne__(self, other):
        """Returns true if both objects are not equal"""
        return not self == other



# coding: utf-8

# flake8: noqa
"""
    Wodby API Client

    Wodby Developer Documentation https://wodby.com/docs/dev  # noqa: E501

    OpenAPI spec version: 3.0.5
    
    Generated by: https://github.com/swagger-api/swagger-codegen.git
"""


from __future__ import absolute_import

# import models into model package
from wodby.models.app import App
from wodby.models.backup import Backup
from wodby.models.domain import Domain
from wodby.models.git_repo import GitRepo
from wodby.models.instance import Instance
from wodby.models.instance_type import InstanceType
from wodby.models.org import Org
from wodby.models.request_app_create import RequestAppCreate
from wodby.models.request_app_create_git import RequestAppCreateGit
from wodby.models.request_app_create_services import RequestAppCreateServices
from wodby.models.request_instance_create import RequestInstanceCreate
from wodby.models.request_instance_create_git import RequestInstanceCreateGit
from wodby.models.request_instance_deploy import RequestInstanceDeploy
from wodby.models.request_instance_deploy_codebase import RequestInstanceDeployCodebase
from wodby.models.response_task import ResponseTask
from wodby.models.response_task_app import ResponseTaskApp
from wodby.models.response_task_instance import ResponseTaskInstance
from wodby.models.server import Server
from wodby.models.stack import Stack
from wodby.models.stack_service import StackService
from wodby.models.task import Task
from wodby.models.user import User
from wodby.models.uuid import Uuid



# coding: utf-8

"""
    Wodby API Client

    Wodby Developer Documentation https://wodby.com/docs/dev  # noqa: E501

    OpenAPI spec version: 3.0.5
    
    Generated by: https://github.com/swagger-api/swagger-codegen.git
"""


import pprint
import re  # noqa: F401

import six


class StackService(object):
    """NOTE: This class is auto generated by the swagger code generator program.

    Do not edit the class manually.
    """

    """
    Attributes:
      swagger_types (dict): The key is attribute name
                            and the value is attribute type.
      attribute_map (dict): The key is attribute name
                            and the value is json key in definition.
    """
    swagger_types = {
        'docker_image': 'str',
        'id': 'str',
        'name': 'str',
        'title': 'str',
        'type': 'str',
        'type_title': 'str'
    }

    attribute_map = {
        'docker_image': 'docker_image',
        'id': 'id',
        'name': 'name',
        'title': 'title',
        'type': 'type',
        'type_title': 'type_title'
    }

    def __init__(self, docker_image=None, id=None, name=None, title=None, type=None, type_title=None):  # noqa: E501
        """StackService - a model defined in Swagger"""  # noqa: E501

        self._docker_image = None
        self._id = None
        self._name = None
        self._title = None
        self._type = None
        self._type_title = None
        self.discriminator = None

        if docker_image is not None:
            self.docker_image = docker_image
        if id is not None:
            self.id = id
        if name is not None:
            self.name = name
        if title is not None:
            self.title = title
        if type is not None:
            self.type = type
        if type_title is not None:
            self.type_title = type_title

    @property
    def docker_image(self):
        """Gets the docker_image of this StackService.  # noqa: E501


        :return: The docker_image of this StackService.  # noqa: E501
        :rtype: str
        """
        return self._docker_image

    @docker_image.setter
    def docker_image(self, docker_image):
        """Sets the docker_image of this StackService.


        :param docker_image: The docker_image of this StackService.  # noqa: E501
        :type: str
        """

        self._docker_image = docker_image

    @property
    def id(self):
        """Gets the id of this StackService.  # noqa: E501


        :return: The id of this StackService.  # noqa: E501
        :rtype: str
        """
        return self._id

    @id.setter
    def id(self, id):
        """Sets the id of this StackService.


        :param id: The id of this StackService.  # noqa: E501
        :type: str
        """

        self._id = id

    @property
    def name(self):
        """Gets the name of this StackService.  # noqa: E501


        :return: The name of this StackService.  # noqa: E501
        :rtype: str
        """
        return self._name

    @name.setter
    def name(self, name):
        """Sets the name of this StackService.


        :param name: The name of this StackService.  # noqa: E501
        :type: str
        """

        self._name = name

    @property
    def title(self):
        """Gets the title of this StackService.  # noqa: E501


        :return: The title of this StackService.  # noqa: E501
        :rtype: str
        """
        return self._title

    @title.setter
    def title(self, title):
        """Sets the title of this StackService.


        :param title: The title of this StackService.  # noqa: E501
        :type: str
        """

        self._title = title

    @property
    def type(self):
        """Gets the type of this StackService.  # noqa: E501


        :return: The type of this StackService.  # noqa: E501
        :rtype: str
        """
        return self._type

    @type.setter
    def type(self, type):
        """Sets the type of this StackService.


        :param type: The type of this StackService.  # noqa: E501
        :type: str
        """

        self._type = type

    @property
    def type_title(self):
        """Gets the type_title of this StackService.  # noqa: E501


        :return: The type_title of this StackService.  # noqa: E501
        :rtype: str
        """
        return self._type_title

    @type_title.setter
    def type_title(self, type_title):
        """Sets the type_title of this StackService.


        :param type_title: The type_title of this StackService.  # noqa: E501
        :type: str
        """

        self._type_title = type_title

    def to_dict(self):
        """Returns the model properties as a dict"""
        result = {}

        for attr, _ in six.iteritems(self.swagger_types):
            value = getattr(self, attr)
            if isinstance(value, list):
                result[attr] = list(map(
                    lambda x: x.to_dict() if hasattr(x, "to_dict") else x,
                    value
                ))
            elif hasattr(value, "to_dict"):
                result[attr] = value.to_dict()
            elif isinstance(value, dict):
                result[attr] = dict(map(
                    lambda item: (item[0], item[1].to_dict())
                    if hasattr(item[1], "to_dict") else item,
                    value.items()
                ))
            else:
                result[attr] = value

        return result

    def to_str(self):
        """Returns the string representation of the model"""
        return pprint.pformat(self.to_dict())

    def __repr__(self):
        """For `print` and `pprint`"""
        return self.to_str()

    def __eq__(self, other):
        """Returns true if both objects are equal"""
        if not isinstance(other, StackService):
            return False

        return self.__dict__ == other.__dict__

    def __ne__(self, other):
        """Returns true if both objects are not equal"""
        return not self == other
